# Contributing

## <a id="openParticipation">Public Participation Invited</a>

The Open Cybersecurity Alliance (OCA) is an [OASIS Open Project](https://oasis-open-projects.org/) and welcomes participation by anyone, whether affiliated with OASIS or not.  Substantive contributions and feedback are invited from all parties, following the common conventions for participation in GitHub public repository projects.  

Participation is expected to be consistent with the [Code of Conduct](https://github.com/opencybersecurityalliance/oca-admin/blob/master/CODE_OF_CONDUCT.md), the [licenses](https://github.com/opencybersecurityalliance/oca-admin/blob/master/LICENSE.md), and the acceptance of our Contributor License Agreement, generally at the time of first contribution. Please see the repository [README](https://github.com/opencybersecurityalliance/oca-admin/blob/master/README.md) for more details.</p>

## <a id="feedback">Feedback</a>

Questions or comments about the OCA's activities may be composed as GitHub issues or comments or may be directed to the project's general email list at oca@lists.oasis-open-projects.org. General questions about OASIS Open Projects may be directed to OASIS staff at op-admin@lists.oasis-open-projects.org
